summaryrefslogtreecommitdiffstats
path: root/kmail/kmlineeditspell.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmlineeditspell.h')
-rw-r--r--kmail/kmlineeditspell.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmail/kmlineeditspell.h b/kmail/kmlineeditspell.h
index 70c8316f..5537b006 100644
--- a/kmail/kmlineeditspell.h
+++ b/kmail/kmlineeditspell.h
@@ -14,7 +14,7 @@ class KMLineEdit : public KPIM::AddresseeLineEdit
Q_OBJECT
TQ_OBJECT
public:
- KMLineEdit(bool useCompletion, TQWidget *tqparent = 0,
+ KMLineEdit(bool useCompletion, TQWidget *parent = 0,
const char *name = 0);
signals:
@@ -22,7 +22,7 @@ signals:
void focusDown();
protected:
// Inherited. Always called by the tqparent when this widget is created.
virtual void loadContacts();
virtual void keyPressEvent(TQKeyEvent*);
@@ -43,7 +43,7 @@ class KMLineEditSpell : public KMLineEdit
Q_OBJECT
TQ_OBJECT
public:
- KMLineEditSpell(bool useCompletion, TQWidget *tqparent = 0,
+ KMLineEditSpell(bool useCompletion, TQWidget *parent = 0,
const char *name = 0);
void highLightWord( unsigned int length, unsigned int pos );
void spellCheckDone( const TQString &s );
@@ -22,7 +22,7 @@ signals:
void focusDown();
protected:
- // Inherited. Always called by the tqparent when this widget is created.
+ // Inherited. Always called by the parent when this widget is created.
virtual void loadContacts();
virtual void keyPressEvent(TQKeyEvent*);